@@ -41,9 +41,7 @@
 #include <math.h>
 #include <limits.h>
 #include <string.h>
-#include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
 
 GNM_PLUGIN_MODULE_HEADER;
 
