@@ -1696,7 +1696,7 @@ gnumeric_hyperlink (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 static GnmFuncHelp const help_transpose[] = {
 	{ GNM_FUNC_HELP_NAME, F_("TRANSPOSE:the transpose of @{matrix}")},
         { GNM_FUNC_HELP_ARG, F_("matrix:range")},
-        { GNM_FUNC_HELP_SEEALSO, "MMULT"},
+        { GNM_FUNC_HELP_SEEALSO, "FLIP,MMULT"},
         { GNM_FUNC_HELP_END}
 };
 
@@ -1729,6 +1729,54 @@ gnumeric_transpose (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	return res;
 }
 
+/***************************************************************************/
+
+static GnmFuncHelp const help_flip[] = {
+	{ GNM_FUNC_HELP_NAME, F_("FLIP:@{matrix} flipped")},
+        { GNM_FUNC_HELP_ARG, F_("matrix:range")},
+        { GNM_FUNC_HELP_ARG, F_("vertical:if true, @{matrix} is flipped vertically, "
+				"otherwise horizontally; defaults to TRUE")},
+        { GNM_FUNC_HELP_SEEALSO, "TRANSPOSE"},
+        { GNM_FUNC_HELP_END}
+};
+
+
+static GnmValue *
+gnumeric_flip (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
+{
+	GnmEvalPos const * const ep = ei->pos;
+        GnmValue const * const matrix = argv[0];
+	int	r, c;
+        GnmValue *res;
+	gboolean vertical = argv[1] ? value_get_as_checked_bool (argv[1]) : TRUE;
+
+	int const cols = value_area_get_width (matrix, ep);
+	int const rows = value_area_get_height (matrix, ep);
+
+	/* Return the value directly for a singleton */
+	if (rows == 1 && cols == 1)
+		return value_dup (value_area_get_x_y (matrix, 0, 0, ep));
+
+	res = value_new_array_non_init (cols, rows);
+
+	if (vertical)
+		for (c = 0; c < cols; ++c) {
+			res->v_array.vals [c] = g_new (GnmValue *, rows);
+			for (r = 0; r < rows; ++r)
+				res->v_array.vals[c][rows - r - 1] = value_dup
+					(value_area_get_x_y (matrix, c, r, ep));
+		}
+	else
+		for (c = 0; c < cols; ++c) {
+			res->v_array.vals [c] = g_new (GnmValue *, rows);
+			for (r = 0; r < rows; ++r)
+				res->v_array.vals[c][r] = value_dup
+					(value_area_get_x_y (matrix, cols - c - 1, r, ep));
+		}
+
+	return res;
+}
+
 /***************************************************************************/
 static GnmFuncHelp const help_array[] = {
         { GNM_FUNC_HELP_NAME, F_("ARRAY:vertical array of the arguments")},
@@ -1840,67 +1888,70 @@ gnumeric_sort (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const lookup_functions[] = {
 	{ "address",   "ff|fbs",
-	  help_address,  gnumeric_address, NULL, NULL, NULL, NULL,
+	  help_address,  gnumeric_address, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "areas", NULL,
-	  help_areas,	NULL,	gnumeric_areas, NULL, NULL, NULL,
+	  help_areas,	NULL,	gnumeric_areas, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "choose", NULL,
-	  help_choose,	NULL,	gnumeric_choose, NULL, NULL, NULL,
+	  help_choose,	NULL,	gnumeric_choose, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "column",     "|A",
-	  help_column,   gnumeric_column, NULL, NULL, NULL, NULL,
+	  help_column,   gnumeric_column, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "columnnumber", "s",
-	  help_columnnumber, gnumeric_columnnumber, NULL, NULL, NULL, NULL,
+	  help_columnnumber, gnumeric_columnnumber, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "columns",   "A",
-	  help_columns, gnumeric_columns, NULL, NULL, NULL, NULL,
+	  help_columns, gnumeric_columns, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hlookup",   "EAf|bb",
-	  help_hlookup, gnumeric_hlookup, NULL, NULL, NULL, NULL,
+	  help_hlookup, gnumeric_hlookup, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hyperlink", "s|s",
-	  help_hyperlink, gnumeric_hyperlink, NULL, NULL, NULL, NULL,
+	  help_hyperlink, gnumeric_hyperlink, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_SUBSET, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "indirect",  "s|b",
-	  help_indirect, gnumeric_indirect, NULL, NULL, NULL, NULL,
+	  help_indirect, gnumeric_indirect, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "index",     "A|fff",
-	  help_index,    NULL, gnumeric_index, NULL, NULL, NULL,
+	  help_index,    NULL, gnumeric_index, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "lookup",    "EA|r",
-	  help_lookup,   gnumeric_lookup, NULL, NULL, NULL, NULL,
+	  help_lookup,   gnumeric_lookup, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "match",     "EA|f",
-	  help_match,    gnumeric_match, NULL, NULL, NULL, NULL,
+	  help_match,    gnumeric_match, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "offset",    "rff|ff",
-	  help_offset,   gnumeric_offset, NULL, NULL, NULL, NULL,
+	  help_offset,   gnumeric_offset, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "row",       "|A",
-	  help_row,      gnumeric_row, NULL, NULL, NULL, NULL,
+	  help_row,      gnumeric_row, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "rows",      "A",
-	  help_rows,     gnumeric_rows, NULL, NULL, NULL, NULL,
+	  help_rows,     gnumeric_rows, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "sheets",      "|A",
-	  help_sheets,     gnumeric_sheets, NULL, NULL, NULL, NULL,
+	  help_sheets,     gnumeric_sheets, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "sheet",      "|?",
-	  help_sheet,     gnumeric_sheet, NULL, NULL, NULL, NULL,
+	  help_sheet,     gnumeric_sheet, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "sort",         "r|f",
-	  help_sort, gnumeric_sort, NULL, NULL, NULL, NULL,
+	  help_sort, gnumeric_sort, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "transpose", "A",
-	  help_transpose, gnumeric_transpose, NULL, NULL, NULL, NULL,
+	  help_transpose, gnumeric_transpose, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "vlookup",   "EAf|bb",
-	  help_vlookup, gnumeric_vlookup, NULL, NULL, NULL, NULL,
+	  help_vlookup, gnumeric_vlookup, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "array", NULL,
-	  help_array, NULL, gnumeric_array, NULL, NULL, NULL,
+	  help_array, NULL, gnumeric_array, NULL, NULL,
+	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+	{ "flip", "A|b",
+	  help_flip, gnumeric_flip, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         {NULL}
