@@ -109,7 +109,7 @@ colrow_is_default (ColRowInfo const *cri)
 
 /**
  * colrow_is_empty :
- * @colrow : #ColRowInfo
+ * @cri : #ColRowInfo
  *
  * TRUE if there is no information in col/row @cri.
  **/
@@ -178,10 +178,9 @@ colrow_free (ColRowInfo *cri)
 
 /**
  * colrow_foreach:
- * @sheet:	the sheet
  * @infos:	The Row or Column collection.
- * @start:	start position (inclusive)
- * @end	:	stop column (inclusive)
+ * @first:	start position (inclusive)
+ * @last:	stop column (inclusive)
  * @callback: (scope call): A callback function which should return TRUE to stop
  *              the iteration.
  * @user_data:	A bagage pointer.
@@ -971,7 +970,7 @@ colrow_visibility (Sheet const *sheet, ColRowVisiblity * const dat,
 		res->first = (j >= first) ? j+1 : first;
 		res->last = i;
 #if 0
-		printf ("%d %d\n", res->index, res->count);
+		g_printerr ("%d %d\n", res->index, res->count);
 #endif
 		dat->elements = g_slist_insert_sorted (dat->elements, res,
 					(GCompareFunc)colrow_index_cmp);
