@@ -3,7 +3,7 @@
  * dependent.c:  Manage calculation dependencies between objects
  *
  * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
- * Copyright (C) 2006-2012 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2006-2013 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -54,7 +54,7 @@ static void dependent_clear_dynamic_deps (GnmDependent *dep);
  * since we need the ability to free en masse.
  */
 
-#ifndef USE_STRING_POOLS
+#ifndef USE_POOLS
 #define USE_POOLS 0
 #endif
 
@@ -231,62 +231,89 @@ gnm_dep_unlink_undo_new (GSList *deps)
 
 #undef DEBUG_EVALUATION
 
-static void cell_dep_eval	   (GnmDependent *dep);
-static void cell_dep_set_expr	   (GnmDependent *dep, GnmExprTop const *new_texpr);
-static GSList *cell_dep_changed	   (GnmDependent *dep);
-static void cell_dep_debug_name    (GnmDependent const *dep, GString *target);
-static void dynamic_dep_eval	   (GnmDependent *dep);
-static GSList *dynamic_dep_changed (GnmDependent *dep);
-static void dynamic_dep_debug_name (GnmDependent const *dep, GString *target);
-static void name_dep_eval	   (GnmDependent *dep);
-static void name_dep_debug_name	   (GnmDependent const *dep, GString *target);
-static void managed_dep_eval	   (GnmDependent *dep);
-static void managed_dep_debug_name (GnmDependent const *dep, GString *target);
+static void
+dummy_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
+{
+}
 
-static GPtrArray *dep_classes = NULL;
-static GnmDependentClass cell_dep_class = {
+static void cell_dep_eval (GnmDependent *dep);
+static void cell_dep_set_expr (GnmDependent *dep, GnmExprTop const *new_texpr);
+static GSList *cell_dep_changed (GnmDependent *dep);
+static GnmCellPos const *cell_dep_pos (GnmDependent const *dep);
+static void cell_dep_debug_name (GnmDependent const *dep, GString *target);
+static const GnmDependentClass cell_dep_class = {
 	cell_dep_eval,
 	cell_dep_set_expr,
 	cell_dep_changed,
+	cell_dep_pos,
 	cell_dep_debug_name,
 };
-static GnmDependentClass dynamic_dep_class = {
-	dynamic_dep_eval,
+
+static GSList *dynamic_dep_changed (GnmDependent *dep);
+static void dynamic_dep_debug_name (GnmDependent const *dep, GString *target);
+static const GnmDependentClass dynamic_dep_class = {
+	dummy_dep_eval,
 	NULL,
 	dynamic_dep_changed,
+	NULL,
 	dynamic_dep_debug_name,
 };
-static GnmDependentClass name_dep_class = {
-	name_dep_eval,
+typedef struct {
+	GnmDependent base;
+	GnmDependent *container;
+	GSList *ranges;
+	GSList *singles;
+} DynamicDep;
+
+static void name_dep_debug_name (GnmDependent const *dep, GString *target);
+static const GnmDependentClass name_dep_class = {
+	dummy_dep_eval,
+	NULL,
 	NULL,
 	NULL,
 	name_dep_debug_name,
 };
-static GnmDependentClass managed_dep_class = {
-	managed_dep_eval,
+
+static void managed_dep_debug_name (GnmDependent const *dep, GString *target);
+static const GnmDependentClass managed_dep_class = {
+	dummy_dep_eval,
+	NULL,
 	NULL,
 	NULL,
 	managed_dep_debug_name,
 };
+
+static GSList *style_dep_changed (GnmDependent *dep);
+static GnmCellPos const *style_dep_pos (GnmDependent const *dep);
+static void style_dep_debug_name (GnmDependent const *dep, GString *target);
+static const GnmDependentClass style_dep_class = {
+	dummy_dep_eval,
+	NULL,
+	style_dep_changed,
+	style_dep_pos,
+	style_dep_debug_name,
+};
 typedef struct {
-	GnmDependent  base;
-	GnmDependent *container;
-	GSList    *ranges;
-	GSList    *singles;
-} DynamicDep;
+	GnmDependent base;
+	GnmCellPos pos;
+} GnmStyleDependent;
+
+
+static GPtrArray *dep_classes = NULL;
 
 void
 dependent_types_init (void)
 {
 	g_return_if_fail (dep_classes == NULL);
 
-	/* Init with a trio of NULL classes so we can access directly */
+	/* Init with a NULL class so we can access directly */
 	dep_classes = g_ptr_array_new ();
 	g_ptr_array_add	(dep_classes, NULL); /* bogus filler */
-	g_ptr_array_add	(dep_classes, &cell_dep_class);
-	g_ptr_array_add	(dep_classes, &dynamic_dep_class);
-	g_ptr_array_add	(dep_classes, &name_dep_class);
-	g_ptr_array_add	(dep_classes, &managed_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&cell_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&dynamic_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&name_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&managed_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&style_dep_class);
 
 #if USE_POOLS
 	micro_few_pool =
@@ -398,11 +425,14 @@ dependent_set_expr (GnmDependent *dep, GnmExprTop const *new_texpr)
 	}
 }
 
-static inline GnmCellPos const *
+GnmCellPos const *
 dependent_pos (GnmDependent const *dep)
 {
 	static GnmCellPos const dummy = { 0, 0 };
-	return dependent_is_cell (dep) ? &GNM_DEP_TO_CELL (dep)->pos : &dummy;
+	int const t = dependent_type (dep);
+	GnmDependentClass *klass = g_ptr_array_index (dep_classes, t);
+
+	return klass->pos ? klass->pos (dep) : &dummy;
 }
 
 
@@ -1139,6 +1169,47 @@ workbook_unlink_3d_dep (GnmDependent *dep)
 	g_hash_table_remove (wb->sheet_order_dependents, dep);
 }
 
+/**
+ * gnm_dep_style_dependency:
+ * @sheet:
+ * @texpr:
+ * @r:
+ *
+ * Returns: (element-type GnmDependent) (transfer full):
+ **/
+GSList *
+gnm_dep_style_dependency (Sheet *sheet,
+			  GnmExprTop const *texpr,
+			  GnmRange const *r)
+{
+	int row, col;
+	GSList *res = NULL;
+
+	/*
+	 * FIXME: Maybe do better for an expression that is just an
+	 * absolute ref.
+	 */
+
+	for (row = r->start.row; row <= r->end.row; row++) {
+		for (col = r->start.col; col <= r->end.col; col++) {
+			GnmStyleDependent *sd = g_new0 (GnmStyleDependent, 1);
+			GnmDependent *dep = &sd->base;
+
+			dep->sheet = sheet;
+			dep->flags = DEPENDENT_STYLE;
+			dep->texpr = NULL;
+			sd->pos.col = col;
+			sd->pos.row = row;
+
+			dependent_set_expr (dep, texpr);
+			dependent_link (dep);
+			res = g_slist_prepend (res, dep);
+		}
+	}
+
+	return res;
+}
+
 /*****************************************************************************/
 
 static void
@@ -1183,6 +1254,12 @@ cell_dep_changed (GnmDependent *dep)
 	return work;
 }
 
+static GnmCellPos const *
+cell_dep_pos (GnmDependent const *dep)
+{
+	return &GNM_DEP_TO_CELL (dep)->pos;
+}
+
 static void
 cell_dep_debug_name (GnmDependent const *dep, GString *target)
 {
@@ -1245,11 +1322,6 @@ dependent_managed_set_sheet (GnmDependent *dep, Sheet *sheet)
 	if (texpr) gnm_expr_top_unref (texpr);
 }
 
-static void
-managed_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
-{
-}
-
 static void
 managed_dep_debug_name (GnmDependent const *dep, GString *target)
 {
@@ -1258,11 +1330,55 @@ managed_dep_debug_name (GnmDependent const *dep, GString *target)
 
 /*****************************************************************************/
 
-static void
-name_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
+static gboolean
+debug_style_deps (void)
 {
+	static int debug = -1;
+	if (debug < 0)
+		debug = gnm_debug_flag ("style-deps");
+	return debug;
 }
 
+static GSList *
+style_dep_changed (GnmDependent *dep)
+{
+	GnmCellPos const *pos = dependent_pos (dep);
+	GnmCell *cell;
+	Sheet *sheet = dep->sheet;
+
+	if (debug_style_deps ())
+		g_printerr ("StyleDep %p at %s changed\n",
+			    dep, cellpos_as_string (pos));
+
+	/*
+	 * If the cell exists, unrender it so format changes can take
+	 * effect.
+	 */
+	cell = sheet_cell_get (sheet, pos->col, pos->row);
+	if (cell)
+		gnm_cell_unrender (cell);
+
+	sheet_redraw_region (sheet,
+			     pos->col, pos->row,
+			     pos->col, pos->row);
+
+	return NULL;
+}
+
+static GnmCellPos const *
+style_dep_pos (GnmDependent const *dep)
+{
+	return &((GnmStyleDependent*)dep)->pos;
+}
+
+static void
+style_dep_debug_name (GnmDependent const *dep, GString *target)
+{
+	g_string_append_printf (target, "StyleDep%p", (void *)dep);
+}
+
+/*****************************************************************************/
+
 static void
 name_dep_debug_name (GnmDependent const *dep, GString *target)
 {
@@ -1271,11 +1387,6 @@ name_dep_debug_name (GnmDependent const *dep, GString *target)
 
 /*****************************************************************************/
 
-static void
-dynamic_dep_eval (G_GNUC_UNUSED GnmDependent *dep)
-{
-}
-
 static GSList *
 dynamic_dep_changed (GnmDependent *dep)
 {
