@@ -832,6 +832,7 @@ fmt_dialog_init_font_page (FormatState *state)
 	/* TODO: How to insert the font box in the right place initially */
 	gtk_widget_show (tmp);
 	gtk_widget_set_vexpand (tmp, TRUE);
+	gtk_widget_set_hexpand (tmp, TRUE);
 	gtk_grid_attach (GTK_GRID (container), tmp, 0, 0, 5, 1);
 
 	font_selector_editable_enters (font_widget, GTK_WINDOW (state->dialog));
@@ -2077,7 +2078,7 @@ cb_fmt_dialog_dialog_destroy (FormatState *state)
 	gnm_style_unref (state->back.style);
 	gnm_style_unref (state->style);
 	gnm_style_unref (state->result);
-	g_object_unref (G_OBJECT (state->gui));
+	g_object_unref (state->gui);
 	g_free (state);
 }
 
@@ -2244,7 +2245,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	fmt_dialog_init_input_msg_page (state);
 
 	ctxt = gtk_widget_get_style_context (GTK_WIDGET (state->dialog));
-	gtk_style_context_get_border_color (ctxt, GTK_STATE_NORMAL, &bc);
+	gtk_style_context_get_border_color (ctxt, GTK_STATE_FLAG_NORMAL, &bc);
 	default_border_color = GO_COLOR_FROM_GDK_RGBA (bc);
 
 	if (pageno == FD_CURRENT)
