@@ -154,8 +154,8 @@ dialog_formula_guru_update_this_parent (GtkTreeIter *parent, FormulaGuruState *s
 	g_return_if_fail (!is_non_fun);
 	g_return_if_fail (fd != NULL);
 
-	text = g_string_append (text, gnm_func_get_name (fd, sheet_get_conventions (state->pos->sheet)->localized_function_names));
-	text = g_string_append (text, "(");
+	g_string_append (text, gnm_func_get_name (fd, sheet_get_conventions (state->pos->sheet)->localized_function_names));
+	g_string_append (text, "(");
 
 	if (gtk_tree_model_iter_children (GTK_TREE_MODEL(state->model), &iter, parent)) {
 		do {
@@ -169,7 +169,7 @@ dialog_formula_guru_update_this_parent (GtkTreeIter *parent, FormulaGuruState *s
 			}
 
 			if (not_first) {
-				text = g_string_append_c (text, go_locale_get_arg_sep ());
+				g_string_append_c (text, go_locale_get_arg_sep ());
 			}
 
 			if (find_origin && origin != NULL) {
@@ -191,18 +191,18 @@ dialog_formula_guru_update_this_parent (GtkTreeIter *parent, FormulaGuruState *s
 					 sheet_get_conventions (state->pos->sheet),
 					 NULL);
 				if (texpr == NULL) {
-					text = g_string_append_c (text, '"');
-					text = g_string_append (text, argument);
-					text = g_string_append_c (text, '"');
+					g_string_append_c (text, '"');
+					g_string_append (text, argument);
+					g_string_append_c (text, '"');
 				} else {
 					if ((GNM_EXPR_GET_OPER (texpr->expr) == GNM_EXPR_OP_NAME)
 					    && expr_name_is_placeholder (texpr->expr->name.name)
 					    && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (state->quote_button))) {
-						text = g_string_append_c (text, '"');
-						text = g_string_append (text, argument);
-						text = g_string_append_c (text, '"');
+						g_string_append_c (text, '"');
+						g_string_append (text, argument);
+						g_string_append_c (text, '"');
 					} else
-						text = g_string_append (text, argument);
+						g_string_append (text, argument);
 					gnm_expr_top_unref (texpr);
 				}
 			}
@@ -213,7 +213,7 @@ dialog_formula_guru_update_this_parent (GtkTreeIter *parent, FormulaGuruState *s
 		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL(state->model), &iter));
 	}
 
-	text = g_string_append_c (text, ')');
+	g_string_append_c (text, ')');
 
 	gtk_tree_store_set (state->model, parent,
 			    FUN_ARG_ENTRY, text->str,
@@ -526,18 +526,18 @@ cb_dialog_formula_guru_destroy (FormulaGuruState *state)
 	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
 
 	if (state->model != NULL)
-		g_object_unref (G_OBJECT (state->model));
+		g_object_unref (state->model);
 	g_free (state->prefix);
 	g_free (state->suffix);
 	g_free (state->pos);
 	if (state->editable)
 		g_object_unref (state->editable);
 	if (state->gui != NULL)
-		g_object_unref (G_OBJECT (state->gui));
+		g_object_unref (state->gui);
 	gnm_expr_entry_enable_tips (wbcg_get_entry_logical (state->wbcg));
 	if (state->tooltip_widget) {
-		g_object_unref (G_OBJECT (state->tooltip_widget));
-		g_object_unref (G_OBJECT (state->tooltip_label));
+		g_object_unref (state->tooltip_widget);
+		g_object_unref (state->tooltip_label);
 	}
 	g_free (state);
 }
@@ -836,8 +836,8 @@ cb_dialog_formula_guru_query_tooltip (G_GNUC_UNUSED GtkWidget  *widget,
 			gnumeric_tooltip_set_style (state->tooltip_label);
 			gnumeric_tooltip_set_style (state->tooltip_widget);
 			gtk_widget_show_all (state->tooltip_widget);
-			g_object_ref (G_OBJECT (state->tooltip_widget));
-			g_object_ref (G_OBJECT (state->tooltip_label));
+			g_object_ref (state->tooltip_widget);
+			g_object_ref (state->tooltip_label);
 		}
 		gtk_tooltip_set_custom (tooltip, state->tooltip_widget);
 		window = gtk_widget_get_toplevel (state->tooltip_widget);
@@ -1087,6 +1087,10 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 	}
 
 	state->dialog = go_gtk_builder_get_widget (state->gui, "formula_guru");
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog),
+					   state->wbcg,
+					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
+
 
 	if (dialog_formula_guru_init (state)) {
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
